==> xmedcon-0.8.9.tgz: include/xmedcon/m-config.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-config.h.in                                                 *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : (X)MedCon template configuration header (configure)      *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-config.h.in,v 1.8 2003/01/12 00:40:16 enlf Exp $
 */

/*
   Copyright (C) 1997-2003 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_CONFIG_H__
#define __M_CONFIG_H__

/* Define some version variables */
#define XMEDCON_MAJOR    (0)
#define XMEDCON_MINOR    (8)
#define XMEDCON_MICRO    (9)
#define XMEDCON_PRGR     "(X)MedCon"
#define XMEDCON_DATE     "15-Jan-2003"
#define XMEDCON_VERSION  "0.8.9"
#define XMEDCON_LIBVERS  "(X)MedCon 0.8.9 by Erik Nolf"

/* Define if format enabled */
#define MDC_INCLUDE_ACR  0
#define MDC_INCLUDE_GIF  0
#define MDC_INCLUDE_INW  0
#define MDC_INCLUDE_ANLZ 0
#define MDC_INCLUDE_CONC 0
#define MDC_INCLUDE_ECAT 0
#define MDC_INCLUDE_INTF 0
#define MDC_INCLUDE_DICM 0
#define MDC_INCLUDE_PNG  0

/* Define decompression program */
#define MDC_DECOMPRESS  "gunzip"

/* Define GLIB related stuff */
#define GLIBSUPPORTED 0

/* Define XMedCon related stuff */
#define XSUPPORTED 0
#if XSUPPORTED
 #define XMDCHELP "http://xmedcon.sourceforge.net"
 #define XMDCLUT  "<unused>/"
 #define XMDCRC   "<unused>/xmedconrc"
#endif

#endif

==> xmedcon-0.9.4.tgz: include/xmedcon/m-config.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-config.h.in                                                 *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : (X)MedCon template configuration header (configure)      *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-config.h.in,v 1.12 2004/01/04 22:36:16 enlf Exp $
 */

/*
   Copyright (C) 1997-2004 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_CONFIG_H__
#define __M_CONFIG_H__

/* Define some version variables */
#define XMEDCON_MAJOR    (0)
#define XMEDCON_MINOR    (9)
#define XMEDCON_MICRO    (4)
#define XMEDCON_PRGR     "(X)MedCon"
#define XMEDCON_DATE     "08-Apr-2004"
#define XMEDCON_VERSION  "0.9.4"
#define XMEDCON_LIBVERS  "(X)MedCon 0.9.4 by Erik Nolf"

/* Define if format enabled */
#define MDC_INCLUDE_ACR  0
#define MDC_INCLUDE_GIF  0
#define MDC_INCLUDE_INW  0
#define MDC_INCLUDE_ANLZ 0
#define MDC_INCLUDE_CONC 0
#define MDC_INCLUDE_ECAT 0
#define MDC_INCLUDE_INTF 0
#define MDC_INCLUDE_DICM 0
#define MDC_INCLUDE_PNG  0

/* Define some machine dependencies */
#define MDC_WORDS_BIGENDIAN  0
#define MDC_SIZEOF_SHORT     2
#define MDC_SIZEOF_INT       4
#define MDC_SIZEOF_LONG      4
#define MDC_ENABLE_LONG_LONG 0

#if MDC_ENABLE_LONG_LONG
#define MDC_SIZEOF_LONG_LONG 
#endif


/* Define decompression program */
#define MDC_DECOMPRESS  "gunzip"

/* Define GLIB related stuff */
#define GLIBSUPPORTED 0

/* Define XMedCon related stuff */
#define XSUPPORTED 0
#if XSUPPORTED
#  define XMDCHELP "http://xmedcon.sourceforge.net"
#  ifdef _WIN32
#    define XMDCLUT  "C:\\Program Files\\XMedCon\\etc\\"
#    define XMDCRC   "C:\\Program Files\\XMedCon\\etc\\xmedconrc"
#  else
#    define XMDCLUT  "<unused>/"
#    define XMDCRC   "<unused>/xmedconrc"
#  endif
#endif

#endif
